#!/bin/bash
# Copyright (C) SWsoft, 1999-2007. All rights reserved.
#
# Distribution detector.

function get_rh_ver()
{
	local dist=$1
	local id=$2
	local rel ver 

	if grep -q "Red Hat Enterprise Linux" /etc/redhat-release 2>/dev/null
	then
		dist=rhel
	fi	
	rel=`rpm -q --last "${id}" 2>/dev/null | grep "${id}-" | head -n 1`
	[ $? -ne 0 -o -z "${rel}" ] && return 1

	ver=`echo "${rel}" | sed -e 's/^'${id}'-\([0-9]*\).*/\1/'`
	[ $? -ne 0 -o -z "${ver}" ] && return 1

	echo "${dist}-${ver}"
	exit 0
}

function get_sl_ver()
{
	local dist=$1
	local file=$2

	ver=`grep -m1 "Slackware " ${file} | sed -e 's/^Slackware\ \([0-9]*\.[0-9]*\).*/\1/'`
	echo "${dist}-${ver}"
	exit 0
}

function get_file_ver()
{
	local file="$1"
	local id="$2"
	local dist="$3"
	local ver

	if ! grep -q "${id}" $file 2>/dev/null; then
	    return 1
	fi
	ver=`grep "${id}" ${file} | head -n1 | sed -e 's/^'"${id}"' \([0-9]*\.[0-9]*\).*/\1/'`
	echo "${dist}-${ver}"
	exit 0
}

if [ -f "/etc/redhat-release" ]; then
	get_rh_ver redhat redhat-release
	get_rh_ver rhel enterprise-release
	get_rh_ver fedora-core fedora-release
	get_rh_ver centos centos-release
fi

if [ -f "/etc/SuSE-release" ]; then
	get_rh_ver suse suse-release
	get_rh_ver sles sles-release
	get_rh_ver sles sled-release
	get_file_ver /etc/SuSE-release 'SuSE Linux' suse
fi

if [ -f "/etc/debian_version" ]; then
	ver=`cat /etc/debian_version`
	echo "debian-${ver}"
	exit 0
fi

if [ -f "/etc/mandrakelinux-release" ]; then
	get_rh_ver mandrake mandrakelinux-release
fi

if [ -f "/etc/mandrake-release" ]; then
	get_rh_ver mandrake mandrake-release
fi

if [ -f "/etc/slackware-version" ]; then
	get_sl_ver slackware /etc/slackware-version
fi

if [ -f "/etc/slackware-release" ]; then
	get_sl_ver slackware /etc/slackware-release
fi

if [ -f "/etc/gentoo-release" ]; then
	echo "gentoo"
	exit 0
fi


echo "Error: Distribution not detected" >&2
exit 1



